@@ -71,7 +71,7 @@ def main():
         svg_draw.save_SVG(option.arguments.output_svg_file,svg_text)
 
     if option.arguments.output_png_file!=None:
-        await svg_draw.save_png(option.arguments.output_png_file,svg_text)
+        loop.run_until_complete(svg_draw.save_png(option.arguments.output_png_file,svg_text))
 
 
 
